import jwt from 'jsonwebtoken';

const maintenanceMiddleware = (req, res, next) => {
  const maintenanceMode = process.env.MAINTENANCE_MODE === 'true';
  const SECRET_KEY = process.env.JWT_SECRET || 'mysecretkey';

  if (!maintenanceMode) {
    return next(); // السماح بالوصول إذا لم يكن في وضع الصيانة
  }

  // التحقق من التوكن
  const token = req.cookies.token;
  if (!token) {
    return res.status(503).json({ message: 'The site is under maintenance. Please try again later.' });
  }

  try {
    const decoded = jwt.verify(token, SECRET_KEY);

    // السماح للإدارة فقط
    if (decoded.role === 'admin') {
      return next();
    }

    return res.status(503).json({ message: 'The site is under maintenance. Please try again later.' });
  } catch (err) {
    return res.status(503).json({ message: 'The site is under maintenance. Please try again later.' });
  }
};

export default maintenanceMiddleware;

  