import express from 'express';
import cors from 'cors';
import cookieParser from 'cookie-parser';
import dotenv from 'dotenv';
import verifyToken from './backpage/verifyToken.js';
import db from './backpage/db.js';
import { fileURLToPath } from 'url';
import loginRouter from './backpage/Login.js'; // استيراد ملف Login.js
import logoutRouter from './backpage/Logout.js'; // استخدام named import
import registerRouter from './backpage/Register.js'; // استيراد صفحة التسجيل
import path from 'path';
//import maintenanceMiddleware from './backpage/maintenanceMiddleware.js'; // يستخدم في حال وجود صيانة للموقع
import alaqsamRouter from './backpage/Alaqsam.js';
import fr1Router from './backpage/Fr1.js';
import fr2Router from './backpage/Fr2.js';
import areasRouter from './backpage/Areas.js'
import citiesRouter from './backpage/Cities.js';
import modelsRouter from './backpage/Modl.js';
import adminadsRouter from './backpage/AdminAds.js';
import useradsRouter from './backpage/UserAds.js';
import adminuserRouter from './backpage/Admins.js';
import adminsRouter from './backpage/Admins.js';
import adminnewRouter from './backpage/AdminNew.js';
import adminsAdsAllRouter from './backpage/AdmnAdsall.js';
import adminsAdsshowRouter from './backpage/AdminAdsshow.js';
import adminsAdsshoweditRouter from './backpage/AdminAdsshowedit.js';
import visibleRouter from './backpage/Visible.js';
import userme from './backpage/UserMe.js';
import userdelete from './backpage/UserMe.js';
import userupdate from './backpage/UserUpdate.js'
import useradsall from './backpage/UserAdsall.js';
import userAdsshowRouter from './backpage/UserAdsshow.js';
import useradsdeleteRouter from './backpage/UserAdsdelete.js'
import useradsshoweditRouter from './backpage/UserAdsshowedit.js';
import adsRouter from './backpage/Ads.js';






dotenv.config(); // تحميل المتغيرات من .env

const app = express();
const PORT = process.env.PORT || 5000;

const isProduction = process.env.NODE_ENV === 'production';
const frontendURL = isProduction ? 'https://ads2030.com' : 'http://localhost:3000';

// إعداد CORS
app.use(cors({
    origin: frontendURL,
    credentials: true,
    methods: ['GET', 'POST', 'PUT', 'DELETE'],
    allowedHeaders: ['Content-Type', 'Authorization'],
}));

//app.use(cors({ origin: 'http://localhost:3000', credentials: true }));

app.use(cookieParser());
app.use(express.json());

// Middleware الصيانة
//app.use(maintenanceMiddleware);

app.get('/api/protected', verifyToken, (req, res) => {
res.json({ role: req.user.role, id: req.user.id, message: 'Authenticated successfully' });
});
    
const __filename = fileURLToPath(import.meta.url);
const __dirname = path.dirname(__filename);
app.use('/uploadsadmin', express.static(path.join(__dirname, 'uploadsadmin'))); // مسار الصور
app.use('/uploadsads', express.static(path.join(__dirname, 'uploadsads')));

// تقديم ملفات React
if (isProduction) {
    app.use(express.static(path.join(__dirname, '../build')));
    app.get('*', (req, res) => {
        res.sendFile(path.join(__dirname, '../build', 'index.html'));
    });
}

// الادارة
app.use('/api', registerRouter); // تسجيل مستخدم جديد
app.use('/api', loginRouter); // تسجيل الدخول
app.use('/api', logoutRouter); // تسجيل الخروج
app.use('/api/alaqsam', alaqsamRouter); // الأقسام اضافة تعديل حذف عرض
app.use('/api/alfro', fr1Router);
app.use('/api/alfroo', fr2Router);
app.use('/api/areas', areasRouter);
app.use('/api/cities', citiesRouter);
app.use('/api/modl', modelsRouter);

app.use('/api/adminuser', adminuserRouter); //  تعديل وحذف المستخدمين
app.use('/api/adminnew', adminnewRouter); //  تعديل وحذف المستخدمين
app.use('/api/admins', adminsRouter); //  المستخدمين

app.use('/api/adminads', adminadsRouter); // اضافة الاعلان
app.use('/api/adminadsall', adminsAdsAllRouter); // الاعلانات
app.use('/api/adminadsshow', adminsAdsshowRouter); // تفاصيل الاعلان
app.use('/api/adminadsshowedit', adminsAdsshoweditRouter); // تعديل الاعلان
app.use('/api/adminadsvisible', visibleRouter); // اخفاء واظهار الاعلان

// المستخدمين
app.use('/api/userme' , userme); // بيانات المستخدمين
app.use('/api/userupdate' , userupdate); // تعديل بيانات المستخدم
app.use('/api/userdelete' , userdelete); // حذف حساب المستخدم

app.use('/api/userads' , useradsRouter); // إضافة حذف تعديل اعلان المستخدم
app.use('/api/useradsall' , useradsall); // عرض اعلان المستخدم
app.use('/api/useradsshow', userAdsshowRouter); // تفاصيل الاعلان
app.use('/api/useradsdelete', useradsdeleteRouter); // حذف الاعلان
app.use('/api/useradsshowedit', useradsshoweditRouter); // تعديل الاعلان

// الاعلانات الصفحة الرئيسية
app.use('/api/', adsRouter); // الاعلانات الرئيسية


// بدء الخادم
app.listen(PORT, () => {
    console.log(`الخادم يعمل على المنفذ ${PORT}`);
});