import React, { useEffect, useState } from "react";
import { Link } from "react-router-dom";
import axios from "axios";
import "./Home.css";
const Home = () => {
  const [ads, setAds] = useState([]);
  const [filteredAds, setFilteredAds] = useState([]);
  const [visibleAdsCount, setVisibleAdsCount] = useState(50); // عدد الإعلانات المرئية
  const adsPerPage = 50; // عدد الإعلانات لكل صفحة

  const [alaqsam, setAlaqsam] = useState([]);
  const [alfro, setAlfro] = useState([]);
  const [alfroo, setAlfroo] = useState([]);
  const [selectedQsm, setSelectedQsm] = useState(null);
  const [selectedAlfr1, setSelectedAlfr1] = useState(null);
  const [selectedAlfr2, setSelectedAlfr2] = useState(null);
  const [searchQuery, setSearchQuery] = useState("");
  const [areas, setAreas] = useState([]);
  const [selectedArea, setSelectedArea] = useState("");

  // جلب البيانات
useEffect(() => {
  let isFetching = false;

  const fetchInitialData = async () => {
    
    if (isFetching) return; // منع التكرار
    isFetching = true;

    const cachedAds = localStorage.getItem("ads");
    const cachedCategories = localStorage.getItem("categories");
    const cachedAreas = localStorage.getItem("areas");

    // إذا كانت البيانات مخزنة، استخدمها
    if (cachedAds && cachedCategories && cachedAreas) {
      setAds(JSON.parse(cachedAds));
      setFilteredAds(JSON.parse(cachedAds));
      setAlaqsam(JSON.parse(cachedCategories));
      setAreas(JSON.parse(cachedAreas));
      return;
    }

    // إذا لم تكن البيانات مخزنة، قم بجلبها
    try {
      const [adsResponse, categoriesResponse, areasResponse] = await Promise.all([
        axios.get("https://ads2030.com/api/public-ads"),
        axios.get("https://ads2030.com/api/public-categories"),
        axios.get("https://ads2030.com/api/public-areas"),
      ]);

      const sortedAds = adsResponse.data.sort(
        (a, b) => new Date(b.datestart) - new Date(a.datestart)
      );

      // تخزين البيانات في `localStorage`
      localStorage.setItem("ads", JSON.stringify(sortedAds));
      localStorage.setItem("categories", JSON.stringify(categoriesResponse.data));
      localStorage.setItem("areas", JSON.stringify(areasResponse.data));

      setAds(sortedAds);
      setFilteredAds(sortedAds);
      setAlaqsam(categoriesResponse.data);
      setAreas(areasResponse.data);
    } catch (error) {
      console.error("Error fetching initial data:", error.message);
    }
  };

  fetchInitialData();
}, []);





  // الفلترة
  useEffect(() => {
    const filterAds = () => {
      const matchesSearch = (ad) =>
        ad.adresads.toLowerCase().includes(searchQuery.toLowerCase());
      const matchesQsm = (ad) =>
        selectedQsm ? ad.alaqsamid === parseInt(selectedQsm) : true;
      const matchesAlfr1 = (ad) =>
        selectedAlfr1 ? ad.alfroid === parseInt(selectedAlfr1) : true;
      const matchesAlfr2 = (ad) =>
        selectedAlfr2 ? ad.alfrooid === parseInt(selectedAlfr2) : true;
      const matchesArea = (ad) =>
        selectedArea ? ad.areasid === parseInt(selectedArea) : true;

      const filtered = ads.filter(
        (ad) =>
          matchesSearch(ad) &&
          matchesQsm(ad) &&
          matchesAlfr1(ad) &&
          matchesAlfr2(ad) &&
          matchesArea(ad)
      );
      setFilteredAds(filtered);
      setVisibleAdsCount(50); // إعادة ضبط الإعلانات المرئية عند تغيير الفلترة
    };

    filterAds();
  }, [ads, searchQuery, selectedQsm, selectedAlfr1, selectedAlfr2, selectedArea]);

  // جلب الفروع بناءً على القسم أو الفروع الأخرى
  const handleQsmClick = async (qsmId) => {
    setSelectedQsm(qsmId);
    setSelectedAlfr1(null);
    setSelectedAlfr2(null);
    setAlfroo([]);
    try {
      const response = await axios.get(`https://ads2030.com/api/public-subcategories?categoryId=${qsmId}`);
      setAlfro(response.data);
    } catch (error) {
    }
  };

  const handleAlfr1Click = async (alfr1Id) => {
    setSelectedAlfr1(alfr1Id);
    setSelectedAlfr2(null);
    try {
      const response = await axios.get(`https://ads2030.com/api/public-subsubcategories?subcategoryId=${alfr1Id}`);
      setAlfroo(response.data);
    } catch (error) {
    }
  };

  const handleAlfr2Click = (alfr2Id) => {
    setSelectedAlfr2(alfr2Id);
  };

  // زر "إظهار المزيد"
  const visibleAds = filteredAds.slice(0, visibleAdsCount);
  const handleLoadMore = () => {
    setVisibleAdsCount((prevCount) => prevCount + adsPerPage);
  };

  // إعادة تعيين الفلاتر
  const handleHomeClick = () => {
    setSelectedQsm(null);
    setSelectedAlfr1(null);
    setSelectedAlfr2(null);
    setSelectedArea("");
    setAlfro([]);
    setAlfroo([]);
  };

  

// اطار منبثق داخل الهيدر الأول يظهر ويختفي ديناميكيًا
const [showAdFrame, setShowAdFrame] = useState(false);
useEffect(() => {
  const toggleAdFrame = () => {
    setShowAdFrame(true);
    setTimeout(() => setShowAdFrame(false), 10000);
  };

  // تشغيل الإطار لأول مرة
  toggleAdFrame();

  // تكرار كل دقيقة
  const intervalId = setInterval(toggleAdFrame, 60000);

  return () => {
    clearInterval(intervalId); // تنظيف عند الخروج
  };
}, []);


return (
  <div className="home-page">

    <div className="home">
      {/* الهيدر الأول */}
      <header className="header header1">
        <div className="logo">
          <img src="/logo/001.png" alt="Logo" className="logo-image" />
        </div>
        {/* الإطار المتباين */}
        {showAdFrame && (
          <div className="ad-frame">
            خدمة إعلانية
          </div>
        )}
        <div className="site-name">إعلانات 2030</div>
      </header>

        {/* الهيدر الثاني */}
        <header className="header header2">
          <button className="button">
            <Link to="/login">تسجيل الدخول</Link>
          </button>
          <button className="button">
            <Link to="/register">تسجيل جديد</Link>
          </button>
        </header>

        {/* الهيدر الثالث */}
        <header className="header header3">
          <div className="scroll-container">
            <button className="button" onClick={handleHomeClick}>
              الرئيسية
            </button>
            {alaqsam.map((qsm) => (
              <button
                key={qsm.id}
                className={`button ${selectedQsm === qsm.id ? "active" : ""}`}
                onClick={() => handleQsmClick(qsm.id)}
              >
                {qsm.qsm}
              </button>
            ))}
          </div>
        </header>

        {/* الهيدر الرابع */}
        {selectedQsm && alfro.length > 0 && (
          <header className="header header4">
            <div className="scroll-container">
              {alfro.map((fr1) => (
                <button
                  key={fr1.id}
                  className={`button ${selectedAlfr1 === fr1.id ? "active" : ""}`}
                  onClick={() => handleAlfr1Click(fr1.id)}
                >
                  {fr1.alfr1}
                </button>
              ))}
            </div>
          </header>
        )}

        {/* الهيدر الخامس */}
        {selectedAlfr1 && alfroo.length > 0 && (
          <header className="header header5">
            <div className="scroll-container">
              {alfroo.map((fr2) => (
                <button
                  key={fr2.id}
                  className={`button ${selectedAlfr2 === fr2.id ? "active" : ""}`}
                  onClick={() => handleAlfr2Click(fr2.id)}
                >
                  {fr2.alfr2}
                </button>
              ))}
            </div>
          </header>
        )}

        {/* الجسم الرئيسي */}
        <div className="main-content">
          {/* البحث */}
          <aside className="sidebar">
            <h3>البحث عن الإعلانات</h3>
            <input
              type="text"
              placeholder="بحث بالكلمات..."
              value={searchQuery}
              onChange={(e) => setSearchQuery(e.target.value)}
            />
            <h3>البحث بتحديد المنطقة</h3>
            <select onChange={(e) => setSelectedArea(e.target.value)} value={selectedArea}>
              <option value="">اختر المنطقة</option>
              {areas.map((area) => (
                <option key={area.id} value={area.id}>
                  {area.area}
                </option>
              ))}
            </select>
          </aside>

          {/* الإعلانات */}
          <section className="ads-section">
  {visibleAds.map((ad) => (
    <div key={ad.id} className="ad-card">
      {/* صورة الإعلان */}
      <Link to={`/hometag/${ad.id}`}>
      <img src={`http://localhost:3001/uploadsads/${ad.img1}`} alt="Ad Image" className="ad-image" />
      </Link>

      {/* تفاصيل الإعلان */}
      <div className="ad-details">
        {/* العنوان (قابل للضغط) */}
        <h4 className="ad-title">
          <Link to={`/hometag/${ad.id}`} className="ad-link">
            {ad.adresads}
          </Link>
        </h4>

        {/* المعلومات الإضافية */}
        <div className="ad-location-container">
          <p className="ad-location">#{ad.id || "غير متوفرة"}</p>
          <p className="ad-location">{ad.area || "غير متوفرة"}</p>
          <p className="ad-city">{ad.city || "غير متوفرة"}</p>
          <p className="ad-username">{ad.useradsid || "غير متوفر"}</p>
          <p className="ad-date">{" "}{ad.datestart ? new Date(ad.datestart).toLocaleDateString("en-GB").replace(/\//g, "-") : "غير متوفر"}</p>
        </div>
      </div>
    </div>
  ))}

  {/* زر إظهار المزيد */}
  {visibleAdsCount < filteredAds.length && (
    <button className="load-more-button" onClick={handleLoadMore}>
      إظهار المزيد
    </button>
  )}
</section>

        </div>
      </div>

      {/* الفوتر */}
      <footer className="footer"><p>2025 © ads2030.com جميع الحقوق محفوظة</p><p><Link to="/termsandprivacy">الشروط والأحكام</Link></p></footer>
    </div>
  );
};

export default Home;

/* © */