import React, { useState } from 'react';
import axios from 'axios';
import { Link, useNavigate } from 'react-router-dom';
import './Login.css';

const Login = () => {
  const [email, setEmail] = useState('');
  const [password, setPassword] = useState('');
  const navigate = useNavigate();
  const [message, setMessage] = useState('');

  const handleSubmit = async (e) => {
    e.preventDefault();

    try {
        const response = await axios.post('https://ads2030.com/api/login', {
            email,
            password,
        }, { withCredentials: true });

        if(response.data.visible === 0){
         // setMessage(response.data.message);
          setMessage('الحساب غير نشط راجع الإدارة للتفعيل')
        } else
        if (response.data.role === 'admin') {
            navigate('/adminindex'); // التوجيه إلى لوحة التحكم الخاصة بالمدير
        } else if (response.data.role === 'user') {
            navigate('/userindex'); // التوجيه إلى لوحة التحكم الخاصة بالمستخدم
        }
    } catch (error) {
        setMessage(error.response?.data?.message || 'Login failed');
    }
};


return (
  <div className="login-page">
    {/* الهيدر الأول */}
      {/* الهيدر الأول */}
      <header className="header header1">
  {/* اللوجو على اليسار */}
  <img src="/logo/001.png" alt="Logo" className="logo-image" />
  
  {/* عنوان الموقع على اليمين */}
  <span className="site-name">إعلانات 2030</span>
</header>

    {/* الهيدر الثاني */}
<header className="header header2">
  <div className="button-container">
    <button className="button">
      <Link to="/">الرئيسية</Link>
    </button>               
    <button className="button">
      <Link to="/login">تسجيل الدخول</Link>
    </button>
    <button className="button">
      <Link to="/register">تسجيل جديد</Link>
    </button>
  </div>
</header>

    {/* قسم تسجيل الدخول */}
    <div className="login-container">
      <h1 className="login-title">تسجيل الدخول</h1>
      {message && <p className="login-message">{message}</p>}
      <form className="login-form" onSubmit={handleSubmit}>
        <div>
          <input
            type="email"
            name="email"
            placeholder="البريد الإلكتروني"
            value={email}
            onChange={(e) => setEmail(e.target.value)}
           // required
            className="login-input"
          />
        </div>
        <div>
          <input
            type="password"
            placeholder="كلمة المرور"
            value={password}
            onChange={(e) => setPassword(e.target.value)}
           // required
            className="login-input"
          />
        </div>
        <div>
          <button type="submit" className="login-button">
            تسجيل الدخول
          </button>
        </div>
      </form>
    </div>
  </div>
);
};

export default Login;
