import React, { useEffect, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { getAuthDetails,/* logout */} from '../authService';
import axios from 'axios';
import './AdminAdsshow.css'

const AdminAdsshow = ({ adId, onBack }) => {
  
  const navigate = useNavigate();
  const [userRole, setUserRole] = useState(null);


  // التوكن والكوكيز
  useEffect(() => {
    const checkAuth = async () => {
      try {
        const authDetails = await getAuthDetails();
        if (authDetails.role !== 'admin') {
          alert("الصفحة المطلوبة غير متوفرة")
          navigate('/login'); // إعادة التوجيه إذا لم يكن المستخدم Admin
        } else {
          setUserRole(authDetails.role); // تعيين الدور
        }
      } catch (error) {
        navigate('/login'); // إعادة التوجيه عند حدوث خطأ
      }
    };
    checkAuth();
  }, [navigate]);

/*
  // تسجيل الخروج
  const handleLogout = async () => {
    try {
      await logout();
      navigate('/login');
    } catch (error) {
      console.error(error.message);
    }
  };
*/

  // تفاصيل الاعلان
  const [ad, setAd] = useState(null);
  // جلب تفاصيل الإعلان
  useEffect(() => {
    if (!adId) {
      console.error('adId غير صالح أو مفقود');
      return;
    }
  
    const fetchAdDetails = async () => {
      try {
        const response = await axios.get(`https://ads2030.com/api/adminadsshow/${adId}`);
        setAd(response.data);
      } catch (error) {

      }
    };
  
    fetchAdDetails();
  }, [adId]);
  
  

  // الحذف والتعديل والاخفاء والاظهار
  const [isEditing, setIsEditing] = useState(false);
  const [editFormData, setEditFormData] = useState({});
  const [newImage, setNewImages] = useState({ img1: null, img2: null, img3: null });
  const [foreignData, setForeignData] = useState({
    alaqsam: [],
    alfro: [],
    alfroo: [],
    model: [],
    areas: [],
    cities: [],
    admins: [],
  });
  const [filteredCities, setFilteredCities] = useState([]);
  const [filteredAlfro, setFilteredAlfro] = useState([]);
  const [filteredAlfroo, setFilteredAlfroo] = useState([]);

    // حذف الإعلان
// حذف الإعلان
const handleDelete = async () => {
  try {
    await axios.delete(`https://ads2030.com/api/adminads/delete/${adId}`);
    alert('تم حذف الإعلان بنجاح');
   // navigate('/adminadsall'); // العودة إلى صفحة عرض الإعلانات
   onBack()
  } catch (error) {
    alert('حدث خطأ أثناء حذف الإعلان.');
  }
};

  
    // إظهار/إخفاء الإعلان
  // تعديل حالة الظهور
  const toggleVisibility = async () => {
    try {
      const updatedVisibility = ad.is_visible === 1 ? 0 : 1;
      await axios.put(`https://ads2030.com/api/adminadsvisible/toggle/${adId}`, {
        is_visible: updatedVisibility,
      });
      setAd((prev) => ({ ...prev, is_visible: updatedVisibility }));
    } catch (error) {

    }
  };
  
    // بدء التعديل
    const [newImage1, setNewImage1] = useState(null); // تعريف الصور
    const [newImage2, setNewImage2] = useState(null);
    const [newImage3, setNewImage3] = useState(null);
    
    const handleEdit = () => {
      setIsEditing(true);
    
      setEditFormData({
        adresads: ad.adresads || '',
        textads: ad.textads || '',
        phoneadsid: ad.phoneadsid || '',
        useradsid: ad.useradsid || '',
        dateend: ad.dateend || '',
        alaqsamid: ad.alaqsamid || '',
        alfroid: ad.alfroid || '',
        alfrooid: ad.alfrooid || '',
        modelid: ad.modelid || '',
        cash: ad.cash || '',
        areasid: ad.areasid || '',
        citiesid: ad.citiesid || '',
        is_visible: ad.is_visible || 0,
      });
    
      // تحديث الفروع والمدن مباشرةً عند فتح نافذة التعديل
      if (ad.alaqsamid) {
        const relatedAlfro = foreignData.alfro.filter((item) => item.alaqsam_id === parseInt(ad.alaqsamid));
        setFilteredAlfro(relatedAlfro);
      }
    
      if (ad.alfroid) {
        const relatedAlfroo = foreignData.alfroo.filter((item) => item.alfro_id === parseInt(ad.alfroid));
        setFilteredAlfroo(relatedAlfroo);
      }
    
      if (ad.areasid) {
        const relatedCities = foreignData.cities.filter((city) => city.areas_id === parseInt(ad.areasid));
        setFilteredCities(relatedCities);
      }
    };
    

  
  // جلب تفاصيل الإعلان
/*  useEffect(() => {
    const fetchAdDetails = async () => {
      try {
        const response = await axios.get(`http://localhost:3001/api/adminadsshow/${id}`);
        setAd(response.data);
        setEditFormData(response.data);
      } catch (error) {
        console.error('Error fetching ad details:', error.message);
      }
    };
    fetchAdDetails();
  }, [id]);
*/
  // جلب البيانات الخارجية
  useEffect(() => {
    const fetchForeignData = async () => {
      try {
        const [alaqsam, alfro, alfroo, model, areas, cities, admins] = await Promise.all([
          axios.get('https://ads2030.com/api/alaqsam'),
          axios.get('https://ads2030.com/api/alfro'),
          axios.get('https://ads2030.com/api/alfroo'),
          axios.get('https://ads2030.com/api/modl'),
          axios.get('https://ads2030.com/api/areas'),
          axios.get('https://ads2030.com/api/cities'),
          axios.get('https://ads2030.com/api/admins'),
        ]);

        setForeignData({
          alaqsam: alaqsam.data,
          alfro: alfro.data,
          alfroo: alfroo.data,
          model: model.data,
          areas: areas.data,
          cities: cities.data,
          admins: admins.data,
        });
      } catch (error) {

      }
    };
    fetchForeignData();
  }, []);

  // تحديث القوائم المفلترة عند تغيير القسم أو المنطقة
  useEffect(() => {
    if (editFormData.alaqsamid) {
      const relatedAlfro = foreignData.alfro.filter((item) => item.alaqsam_id === parseInt(editFormData.alaqsamid));
      setFilteredAlfro(relatedAlfro);
    }

    if (editFormData.alfroid) {
      const relatedAlfroo = foreignData.alfroo.filter((item) => item.alfro_id === parseInt(editFormData.alfroid));
      setFilteredAlfroo(relatedAlfroo);
    }

    if (editFormData.areasid) {
      const relatedCities = foreignData.cities.filter((city) => city.areas_id === parseInt(editFormData.areasid));
      setFilteredCities(relatedCities);
    }
  }, [editFormData.alaqsamid, editFormData.alfroid, editFormData.areasid]);

  // تحديث البيانات أثناء التعديل
  const handleEditChange = (e) => {
    const { name, value } = e.target;
  
    setEditFormData((prev) => ({ ...prev, [name]: value }));
  
    if (name === "alaqsamid") {
      const relatedAlfro = value
        ? foreignData.alfro.filter((item) => item.alaqsam_id === parseInt(value))
        : [];
      setFilteredAlfro(relatedAlfro);
      setFilteredAlfroo([]); // إعادة تعيين الفروع الثانية
      setEditFormData((prev) => ({ ...prev, alfroid: '', alfrooid: '' }));
    }
  
    if (name === "alfroid") {
      const relatedAlfroo = value
        ? foreignData.alfroo.filter((item) => item.alfro_id === parseInt(value))
        : [];
      setFilteredAlfroo(relatedAlfroo);
      setEditFormData((prev) => ({ ...prev, alfrooid: '' }));
    }
  
    if (name === "areasid") {
      const relatedCities = value
        ? foreignData.cities.filter((city) => city.areas_id === parseInt(value))
        : [];
      setFilteredCities(relatedCities);
      setEditFormData((prev) => ({ ...prev, citiesid: '' }));
    }

    if (name === 'dateend') {
      const currentDate = new Date();
      const monthsToAdd = parseInt(value, 10);
      if (!isNaN(monthsToAdd)) {
        const calculatedDate = new Date(
          currentDate.getFullYear(),
          currentDate.getMonth() + monthsToAdd,
          currentDate.getDate()
        );
        setEditFormData((prev) => ({
          ...prev,
          dateend: calculatedDate.toISOString().split('T')[0],
        }));
      }
    }

  };
  
  

  // تحديث الصور أثناء التعديل
  const handleImageChange = (e) => {
    const { name, files } = e.target;
    setNewImages((prev) => ({ ...prev, [name]: files[0] }));
  };

  

  // حفظ التعديلات
  const saveEdit = async (e) => {
    e.preventDefault();
    try {
      const formData = new FormData();
  
      // إضافة الحقول النصية
      for (const key in editFormData) {
        formData.append(key, editFormData[key] || null);
      }
  
      // إضافة الصور
      if (newImage1) formData.append('img1', newImage1);
      if (newImage2) formData.append('img2', newImage2);
      if (newImage3) formData.append('img3', newImage3);
  
     // console.log('Sending FormData:', [...formData.entries()]);
  
      const response = await axios.put(`https://ads2030.com/api/adminadsshowedit/edit/${adId}`, formData, {
        headers: { 'Content-Type': 'multipart/form-data' },
      });
  
      alert(response.data.message);
      onBack()
      setIsEditing(false);
    } catch (error) {
      alert('حدث خطأ أثناء تحديث الإعلان');
    }
  };
  
    
  if (!ad) {
    return <p>جاري تحميل البيانات...</p>;
  }
   

  return (
    <div className="ad-details-container">

      {userRole && <>
       <h1>تفاصيل الاعلان</h1>

       <p className='a'>النوع - {ad.adresads}</p>
      <p className='b'> التفاصيل - {ad.textads}</p>

      <p className='c'>المنطقة: {ad.area || 'غير متوفرة'} - {ad.city || 'غير متوفرة'}</p>
      {/*<p className='d'>المدينة: {ad.city || 'غير متوفرة'}</p>*/}
      <p className='e'>صاحب الاعلان: {ad.useradsid || 'غير متوفرة'}</p>
      <p className='f'>التواصل: {ad.phoneadsid || 'غير متوفرة'}</p>
      <p className='g'>تاريخ الاعلان: {new Date(ad.datestart).toLocaleDateString('en-GB').replace(/\//g, '-')}</p>
      <p className='h'>تاريخ الإنتهاء: {new Date(ad.dateend).toLocaleDateString('en-GB').replace(/\//g, '-')}</p>
      <div  className="ad-details-images">
        <div>
        {ad.img1 && (
        <img
        src={`https://ads2030.com/uploadsads/${ad.img1}`}
        alt={new Date(ad.dateend).toLocaleDateString('en-GB').replace(/\//g, '-')}
      />
)}
    </div><br />
        <div>
        {ad.img2 && (
        <img
        src={`https://ads2030.com/uploadsads/${ad.img2}`}
        alt={new Date(ad.dateend).toLocaleDateString('en-GB').replace(/\//g, '-')}
      />
)}
    </div><br />
        <div>
        {ad.img3 && (
        <img
        src={`https://ads2030.com/uploadsads/${ad.img3}`}
        alt={new Date(ad.dateend).toLocaleDateString('en-GB').replace(/\//g, '-')}
      />
)}
    </div>
      </div>

      <div  className="ad-details-buttons">      
        {/* الحذف والتعديل والاخفاء والاظهار */}
        <button onClick={onBack}>عودة للخلف</button>

                    {/* الأزرار */}
          <button onClick={handleDelete}>حذف الإعلان</button>
          <button onClick={handleEdit}>تعديل الإعلان</button>
          <button onClick={toggleVisibility}>
            {ad.is_visible === 1 ? 'إخفاء الإعلان' : 'إظهار الإعلان'}
          </button>
          </div>


          {/* نافذة التعديل */}
{/* فورم التعديل */}
{isEditing && (
  <div className="edit-ad-container">
    <h2>تعديل الإعلان</h2>
    <form>
      <input
        type="text"
        name="adresads"
        value={editFormData.adresads || ''}
        onChange={handleEditChange}
        placeholder="عنوان الإعلان"
      />
      <textarea
        name="textads"
        value={editFormData.textads || ''}
        onChange={handleEditChange}
        placeholder="وصف الإعلان"
      />
      <input
        type="number"
        name="cash"
        value={editFormData.cash || ''}
        onChange={handleEditChange}
        placeholder="السعر"
      />

      {/* الحقل المنسدل لأسماء المستخدمين */}
      <select name="useradsid" value={editFormData.useradsid || ''} onChange={handleEditChange}>
        <option value="">اختر اسم المستخدم</option>
        {foreignData.admins.map((admin) => (
          <option key={admin.id} value={admin.username}>
            {admin.username}
          </option>
        ))}
      </select>

      {/* الحقل المنسدل لأرقام الهواتف */}
      <select name="phoneadsid" value={editFormData.phoneadsid || ''} onChange={handleEditChange}>
        <option value="">اختر رقم الهاتف</option>
        {foreignData.admins.map((admin) => (
          <option key={admin.id} value={admin.phone}>
            {admin.phone}
          </option>
        ))}
      </select>

{/* الحقل المنسدل للقسم */}
<select name="alaqsamid" value={editFormData.alaqsamid || ''} onChange={handleEditChange}>
  <option value="">اختر القسم</option>
  {foreignData.alaqsam.map((item) => (
    <option key={item.id} value={item.id}>
      {item.qsm}
    </option>
  ))}
</select>
{/* الحقل المنسدل للفرع الأول */}
<select name="alfroid" value={editFormData.alfroid || ''} onChange={handleEditChange}>
  <option value="">اختر الفرع الأول</option>
  {filteredAlfro.map((item) => (
    <option key={item.id} value={item.id}>
      {item.alfr1}
    </option>
  ))}
</select>
{/* الحقل المنسدل للفرع الثاني */}
<select name="alfrooid" value={editFormData.alfrooid || ''} onChange={handleEditChange}>
  <option value="">اختر الفرع الثاني</option>
  {filteredAlfroo.map((item) => (
    <option key={item.id} value={item.id}>
      {item.alfr2}
    </option>
  ))}
</select>
      <select name="areasid" value={editFormData.areasid || ''} onChange={handleEditChange}>
        <option value="">اختر المنطقة</option>
        {foreignData.areas.map((area) => (
          <option key={area.id} value={area.id}>
            {area.area}
          </option>
        ))}
      </select>
{/* الحقل المنسدل للمدينة */}
<select name="citiesid" value={editFormData.citiesid || ''} onChange={handleEditChange}>
  <option value="">اختر المدينة</option>
  {filteredCities.map((city) => (
    <option key={city.id} value={city.id}>
      {city.city}
    </option>
  ))}
</select>
<select name="dateend" onChange={handleEditChange} required>
          <option value="">اختر مدة الانتهاء</option>
          <option value="1">شهر</option>
          <option value="2">شهران</option>
          <option value="3">ثلاثة أشهر</option>
          <option value="6">ستة أشهر</option>
          <option value="12">سنة</option>
        </select>
      <input type="file" name="img1" onChange={(e) => setNewImage1(e.target.files[0])} />
                <input type="file" name="img2" onChange={(e) => setNewImage2(e.target.files[0])} />
                <input type="file" name="img3" onChange={(e) => setNewImage3(e.target.files[0])} />
                <button type="button" onClick={saveEdit}>
        حفظ التعديلات
      </button>
    </form>
  </div>
)}

          
      </>}
      
    </div>
  );
};

export default AdminAdsshow;