import React, { useEffect, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { getAuthDetails, logout } from '../authService';
import Alaqsam from './Alaqsam';
import Fr1 from './Fr1';
import Fr2 from './Fr2';
import Areas from './Areas';
import Cities from './Cities';
import Modl from './Modl';
import AdminAds from './AdminAds';
import AdminUsers from './AdminUsers';
import AdminAdsAll from './AdminAdsall';
import AdminAdsshow from './AdminAdsshow'; // إضافة صفحة تفاصيل الإعلان
import AdminNew from './AdminNew';
import './AdminIndex.css';
import axios from 'axios';


const AdminIndex = () => {
  const navigate = useNavigate();
  const [userRole, setUserRole] = useState(null);


  // الحالة لتحديد الصفحة الحالية
  const [activePage, setActivePage] = useState('dashboard'); // الصفحة الافتراضية
  const [activeAdId, setActiveAdId] = useState(null); // لتخزين معرف الإعلان النشط

  // التحقق من صلاحيات المدير
  useEffect(() => {
    const checkAuth = async () => {
      try {
        const authDetails = await getAuthDetails();
        if (authDetails.role !== 'admin') {
          alert('الصفحة المطلوبة غير متوفرة');
          navigate('/login');
        } else {
          setUserRole(authDetails.role);
          setAdminDetails(authDetails);
        }
      } catch (error) {
        navigate('/login');
      }
    };
    checkAuth();
  }, [navigate]);

  // تسجيل الخروج
  const handleLogout = async () => {
    try {
      await logout();
      navigate('/login');
    } catch (error) {

    }
  };

  // جلب بيانات الإدارة
 // const [adminDetails, setAdminDetails] = useState({username: '',image: '',});

  const [adminDetails, setAdminDetails] = useState(null);

  // جلب بيانات المستخدم بعد تسجيل الدخول


  useEffect(() => {
    const fetchUserData = async () => {
      try {
        if (adminDetails) return; // إذا كانت البيانات موجودة، لا تقم بالجلب
        const response = await axios.get('https://ads2030.com/api/admins/details', { withCredentials: true });
        setAdminDetails(response.data);
      } catch (error) {
        alert('عفوا: يجب تسجيل الدخول.');
        navigate('/login');
      }
    };
  
    fetchUserData();
  }, [navigate, adminDetails]);
  




  // عرض الصفحة بناءً على الحالة
  const renderPage = () => {
    if (activePage === 'adminadsshow') {
      return (
        <AdminAdsshow
          adId={activeAdId} // تمرير معرف الإعلان
          onBack={() => setActivePage('adminadsall')} // العودة إلى صفحة الإعلانات
        />
      );
    }
  
    if (activePage === 'adminadsall') {
      return (
        <AdminAdsAll
          onViewDetails={(id) => {
            setActiveAdId(id); // تعيين معرف الإعلان
            setActivePage('adminadsshow'); // التبديل إلى صفحة تفاصيل الإعلان
          }}
        />
      );
    }
  
    switch (activePage) {
      case 'dashboard':
        return <h2>مرحبًا بك في لوحة تحكم الإدارة
          <><br />
          <img
              src={`https://ads2030.com/uploadsadmin/${adminDetails.image || 'default.png'}`}
              alt="Admin"
             // className="admin-avatar-img"
              style={{marginTop:"30px",width:"40%", borderRadius:"50%"}}
            />
          </>
          </h2>;
            case "adminads":
              return <AdminAds onAdAdded={() => setActivePage("adminadsall")} />;
            case "adminadsall":
              return <AdminAdsAll />;          
      case 'alaqsam':
        return <Alaqsam />;
      case 'fr1':
        return <Fr1 />;
      case 'fr2':
        return <Fr2 />;
      case 'areas':
        return <Areas />;
      case 'cities':
        return <Cities />;
      case 'modl':
        return <Modl />;
      case 'adminnew':
        return <AdminNew />;
      case 'adminusers':
        return <AdminUsers />;
      default:
        return <h2>الصفحة غير موجودة</h2>;
    }
  };

  return (
    <div className="admin-index">
      {userRole && (
        <>
          {/* الهيدر الأول */}
          <header className="admin-header">
            <h1 className="admin-title">لوحة تحكم الإدارة</h1>
            <button className="logout-button" onClick={handleLogout}>
              تسجيل الخروج
            </button>
          </header>

          {/* الهيدر الثاني */}
          <div className="admin-subheader">
            <span className="admin-name">أهلاً وسهلاً ({adminDetails.username})</span>
            <img
              src={`https://ads2030.com/uploadsadmin/${adminDetails.image || 'default.png'}`}
              alt="Admin"
              className="admin-avatar"
            />
          </div>

          {/* الجسم الرئيسي */}
          <div className="admin-main">
            {/* القائمة الجانبية */}
            <aside className="admin-sidebar">
              <nav>
                <ul>
                  <li>
                    <button onClick={() => setActivePage('dashboard')}>الرئيسية</button>
                  </li>
                  <li>
                    <button onClick={() => setActivePage('adminads')}>إعلان جديد</button>
                  </li>
                  <li>
                    <button onClick={() => setActivePage('adminadsall')}>عرض الإعلانات</button>
                  </li>
                  <li>
                    <button onClick={() => setActivePage('adminnew')}>إضافة المستخدمين</button>
                  </li>
                  <li>
                    <button onClick={() => setActivePage('adminusers')}>عرض وتعديل المستخدمين</button>
                  </li>
                  <li>
                    <button onClick={() => setActivePage('alaqsam')}>الأقسام</button>
                  </li>
                  <li>
                    <button onClick={() => setActivePage('fr1')}>الفرع الأول</button>
                  </li>
                  <li>
                    <button onClick={() => setActivePage('fr2')}>الفرع الثاني</button>
                  </li>
                  <li>
                    <button onClick={() => setActivePage('areas')}>المناطق</button>
                  </li>
                  <li>
                    <button onClick={() => setActivePage('cities')}>المدن</button>
                  </li>
                  <li>
                    <button onClick={() => setActivePage('modl')}>الموديل</button>
                  </li>



                  
                </ul>
              </nav>
            </aside>

            {/* محتوى القسم الأيمن */}
            <section className="admin-content">{renderPage()}</section>

          </div>

          {/* الفوتر */}
          <footer className="admin-footer">  2025 © ads2030.com الحقوق محفوظة لـ</footer>
        </>
      )}
    </div>
  );
};

export default AdminIndex;