import React, { useEffect, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { getAuthDetails,/* logout */} from '../authService';
import axios from 'axios'
import './AdminUsers.css'

function AdminUsers() {

  const navigate = useNavigate();
  const [userRole, setUserRole] = useState(null);
  // الكوكيز والتوكن
  useEffect(() => {
    const checkAuth = async () => {
      try {
        const authDetails = await getAuthDetails();
        if (authDetails.role !== 'admin') {
            alert("الصفحة المطلوبة غير متوفرة")
          navigate('/login'); // إعادة التوجيه إذا لم يكن المستخدم Admin
        } else {
          setUserRole(authDetails.role); // تعيين الدور
        }
      } catch (error) {
        navigate('/login'); // إعادة التوجيه عند حدوث خطأ
      }
    };
    checkAuth();
  }, [navigate]);

/*
  // تسجيل الخروج
  const handleLogout = async () => {
    try {
      await logout();
      navigate('/login');
    } catch (error) {

    }
  };
*/

  // المدراء
  const [users, setUsers] = useState([]);
  const [editId, setEditId] = useState(null);
  const [editData, setEditData] = useState({
    username: '',
    email: '',
    role: '',
    phone: '',
    password: '',
    image: null,
    is_visible_a: '',
  });

  useEffect(() => {
    fetchUsers();
  }, []);

  const fetchUsers = async () => {
    try {
      const response = await axios.get('https://ads2030.com/api/adminuser');
      setUsers(response.data);
    } catch (error) {

    }
  };

  const handleEditInputChange = (e) => {
    e.preventDefault()
    const { name, value } = e.target;
    setEditData((prev) => ({ ...prev, [name]: value }));
  };

  const handleFileChange = (e) => {
    e.preventDefault()
    const { name, files } = e.target;
    setEditData((prev) => ({ ...prev, [name]: files[0] }));
  };


  const saveEdit = async (e) => {
    e.preventDefault();
    const data = new FormData();
    for (const key in editData) {
      data.append(key, editData[key]);
    }

    try {
      await axios.put(`https://ads2030.com1/api/adminuser/edit/${editId}`, data, {
        headers: { 'Content-Type': 'multipart/form-data' },
      });
      fetchUsers();
      setEditId(null);
    } catch (error) {

    }
  };

  const cancelEdit = () => {
    setEditId(null);
  };

  const startEdit = (user) => {
    setEditId(user.id);
    setEditData({
      username: user.username,
      email: user.email,
      role: user.role,
      phone: user.phone,
      is_visible_a: user.is_visible_a,
    });
  };

  const deleteUser = async (id) => {
    try {
      const response = await axios.delete(`https://ads2030.com/api/adminuser/delete/${id}`);
      alert(response.data.message);
      fetchUsers();
    } catch (error) {

      alert('حدث خطأ أثناء حذف المستخدم.');
    }
  };
  
  

  return (
<div className="admin-users-container">
  {userRole && (
    <>
      <h1>عرض وتعديل المستخدمين</h1>

      {/* عرض المستخدمين */}
      <ul className="admin-list">
        {users.map((user) => (
          <li key={user.id}>
            {editId === user.id ? (
              // وضع المستخدم في وضع التحرير
<form className="edit-form">
  <div>
    <label htmlFor="username">اسم المستخدم</label>
    <input
      id="username"
      type="text"
      name="username"
      value={editData.username}
      onChange={handleEditInputChange}
    />
  </div>
  <div>
    <label htmlFor="email">البريد الإلكتروني</label>
    <input
      id="email"
      type="email"
      name="email"
      value={editData.email}
      onChange={handleEditInputChange}
    />
  </div>
  <div>
    <label htmlFor="password">كلمة المرور</label>
    <input
      id="password"
      type="password"
      name="password"
      value={editData.password}
      onChange={handleEditInputChange}
      placeholder="كلمة المرور الجديدة (اختياري)"
    />
  </div>
  <div>
    <label htmlFor="phone">رقم الهاتف</label>
    <input
      id="phone"
      type="text"
      name="phone"
      value={editData.phone}
      onChange={handleEditInputChange}
    />
  </div>
  <div>
    <label htmlFor="role">المرتبة</label>
    <select
      id="role"
      name="role"
      value={editData.role}
      onChange={handleEditInputChange}
    >
      <option value="user">مستخدم</option>
      <option value="admin">مدير</option>
    </select>
  </div>
  <div>
    <label htmlFor="is_visible_a">حالة المستخدم</label>
    <select
      id="is_visible_a"
      name="is_visible_a"
      value={editData.is_visible_a}
      onChange={handleEditInputChange}
    >
      <option value="1">نشط</option>
      <option value="0">غير نشط</option>
    </select>
  </div>
  <div>
    <label htmlFor="image">الصورة الشخصية</label>
    <input
      id="image"
      type="file"
      name="image"
      onChange={handleFileChange}
    />
  </div>
  <div className='cnsledte'>
    <button type="button" className="save-button" onClick={saveEdit}>
      حفظ
    </button>
    <button type="button" className="cancel-button" onClick={cancelEdit}>
      تراجع
    </button>
  </div>
</form>

            ) : (
              // عرض المستخدم في وضع العرض العادي
              <div className="user-row">
                <img
                  src={`https://ads2030.com/uploadsadmin/${user.image}`}
                  alt={user.username}
                  className="user-avatar"
                />
                <div className="user-info">
                  <span>
                    <strong>اسم المستخدم:</strong> {user.username}
                  </span>
                  <span>
                    <strong>البريد الإلكتروني:</strong> {user.email}
                  </span>
                  <span>
                    <strong>المرتبة:</strong>{' '}
                    {user.role === 'admin' ? 'مدير' : 'مستخدم'}
                  </span>
                </div>
                <div className="user-actions">
                  <button
                    className="edit-button"
                    onClick={() => startEdit(user)}
                  >
                    تعديل
                  </button>
                  <button
                    className="delete-button"
                    onClick={() => deleteUser(user.id)}
                  >
                    حذف
                  </button>
                </div>
              </div>
            )}
          </li>
        ))}
      </ul>
    </>
  )}
</div>
  )
}

export default AdminUsers