import React, { useEffect, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { getAuthDetails, /* logout */ } from '../authService';
import axios from 'axios'
import './Alaqsam.css';

function Alaqsam() {

  const navigate = useNavigate();
  const [userRole, setUserRole] = useState(null);
  // الكوكيز والتوكن
  useEffect(() => {
    const checkAuth = async () => {
      try {
        const authDetails = await getAuthDetails();
        if (authDetails.role !== 'admin') {
            alert("الصفحة المطلوبة غير متوفرة")
          navigate('/login'); // إعادة التوجيه إذا لم يكن المستخدم Admin
        } else {
          setUserRole(authDetails.role); // تعيين الدور
        }
      } catch (error) {
        navigate('/login'); // إعادة التوجيه عند حدوث خطأ
      }
    };
    checkAuth();
  }, [navigate]);

/*
  // تسجيل الخروج
  const handleLogout = async () => {
    try {
      await logout();
      navigate('/login');
    } catch (error) {

    }
  };
*/

  // الأقسام
  const [alaqsam, setAlaqsam] = useState([]);
  const [newQsm, setNewQsm] = useState('');
  const [editId, setEditId] = useState(null);
  const [editQsm, setEditQsm] = useState('');
  // جلب الأقسام عند تحميل الصفحة
  useEffect(() => {
    fetchAlaqsam();
  }, []);
  const fetchAlaqsam = async () => {
    try {
      const response = await axios.get('https://ads2030.com/api/alaqsam');
      setAlaqsam(response.data);
    } catch (error) {

    }
  };
  const addQsm = async (e) => {
    e.preventDefault();
    try {
      const response = await axios.post('https://ads2030.com/api/alaqsam/add', { qsm: newQsm });
      setAlaqsam([...alaqsam, { id: response.data.id, qsm: newQsm }]);
      setNewQsm('');
    } catch (error) {

    }
  };
  const deleteQsm = async (id) => {
    try {
      await axios.delete(`https://ads2030.com/api/alaqsam/delete/${id}`);
      setAlaqsam(alaqsam.filter((q) => q.id !== id));
    } catch (error) {

    }
  };
  const startEdit = (id, qsm) => {
    setEditId(id);
    setEditQsm(qsm);
  };
  const saveEdit = async () => {
    try {
      await axios.put(`https://ads2030.com/api/alaqsam/edit/${editId}`, { qsm: editQsm });
      setAlaqsam(alaqsam.map((q) => (q.id === editId ? { ...q, qsm: editQsm } : q)));
      setEditId(null);
      setEditQsm('');
    } catch (error) {

    }
  };
  const cancelEdit = () => {
    setEditId(null);
    setEditQsm('');
  };

  return (
    <div className="alaqsam-container">

{userRole && <>
       <h1>أضف قسم جديد</h1>

      {/* فورم إضافة قسم جديد */}
      <form onSubmit={addQsm}>
        <input
          type="text"
          value={newQsm}
          onChange={(e) => setNewQsm(e.target.value)}
          placeholder="أدخل اسم القسم"
          required
        />
        <button type="submit">إضافة قسم</button>
      </form>

      {/* قائمة الأقسام */}
      <ul>
        {alaqsam.map((qsm) => (
          <li key={qsm.id}>
            {editId === qsm.id ? (
              <>
                <input
                  type="text"
                  value={editQsm}
                  onChange={(e) => setEditQsm(e.target.value)}
                />
                <button onClick={saveEdit}>حفظ</button>
                <button onClick={cancelEdit}>تراجع</button>
              </>
            ) : (
              <>
                {qsm.qsm}
                <button onClick={() => startEdit(qsm.id, qsm.qsm)}>تعديل</button>
                <button onClick={() => deleteQsm(qsm.id)}>حذف</button>
              </>
            )}
          </li>
        ))}
      </ul>

      </>}
        
    </div>
  )
}

export default Alaqsam