import React, { useEffect, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { getAuthDetails,/* logout */} from '../authService';
import axios from 'axios'
import './Areas.css';

function Areas() {

  const navigate = useNavigate();
  const [userRole, setUserRole] = useState(null);
  // الكوكيز والتوكن
  useEffect(() => {
    const checkAuth = async () => {
      try {
        const authDetails = await getAuthDetails();
        if (authDetails.role !== 'admin') {
            alert("الصفحة المطلوبة غير متوفرة")
          navigate('/login'); // إعادة التوجيه إذا لم يكن المستخدم Admin
        } else {
          setUserRole(authDetails.role); // تعيين الدور
        }
      } catch (error) {
        navigate('/login'); // إعادة التوجيه عند حدوث خطأ
      }
    };
    checkAuth();
  }, [navigate]);

/*
  // تسجيل الخروج
  const handleLogout = async () => {
    try {
      await logout();
      navigate('/login');
    } catch (error) {

    }
  };
*/

 // المناطق
 const [areas, setAreas] = useState([]);
 const [newArea, setNewArea] = useState('');
 const [editId, setEditId] = useState(null);
 const [editArea, setEditArea] = useState('');

 // جلب المناطق عند تحميل الصفحة
 useEffect(() => {
   fetchAreas();
 }, []);

 const fetchAreas = async () => {
   try {
     const response = await axios.get('https://ads2030.com/api/areas');
     setAreas(response.data);
   } catch (error) {

  }
 };

 const addArea = async (e) => {
   e.preventDefault();

   try {
     const response = await axios.post('https://ads2030.com/api/areas/add', { area: newArea });
     setAreas([...areas, { id: response.data.id, area: newArea }]);
     setNewArea('');
   } catch (error) {

  }
 };

 const deleteArea = async (id) => {
   try {
     await axios.delete(`https://ads2030.com/api/areas/delete/${id}`);
     setAreas(areas.filter((a) => a.id !== id));
   } catch (error) {

  }
 };

 const startEdit = (id, area) => {
   setEditId(id);
   setEditArea(area);
 };

 const saveEdit = async () => {
   try {
     await axios.put(`https://ads2030.com/api/areas/edit/${editId}`, { area: editArea });
     setAreas(areas.map((a) => (a.id === editId ? { ...a, area: editArea } : a)));
     setEditId(null);
     setEditArea('');
   } catch (error) {

  }
 };

 const cancelEdit = () => {
   setEditId(null);
   setEditArea('');
 };

  return (
    <div className="areas-page">

{userRole && <>
       <h1 className="areas-title">أضف منطقة جديدة</h1>

             {/* فورم إضافة منطقة جديدة */}
      <form onSubmit={addArea} className="areas-form">
        <input
          type="text"
          value={newArea}
          onChange={(e) => setNewArea(e.target.value)}
          placeholder="اسم المنطقة"
          required
        />
<br />
        <button type="submit">إضافة منطقة</button>
      </form>

      {/* قائمة المناطق */}
      <ul className="areas-list">
        {areas.map((area) => (
          <li key={area.id} className="areas-item">
            {editId === area.id ? (
              <>
                <input
                  type="text"
                  value={editArea}
                  onChange={(e) => setEditArea(e.target.value)}
                />
                <button className="btn-save" onClick={saveEdit}>حفظ</button>
                <button className="btn-cancel" onClick={cancelEdit}>تراجع</button>
              </>
            ) : (
              <>
                {area.area}
                <button className="btn-edit" onClick={() => startEdit(area.id, area.area)}>تعديل</button>
                <button className="btn-delete" onClick={() => deleteArea(area.id)}>حذف</button>
              </>
            )}
          </li>
        ))}
      </ul>

      </>}
        
    </div>
  )
}

export default Areas