import React, { useEffect, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { getAuthDetails,/* logout */} from '../authService';
import axios from 'axios'
import './Cities.css';

function Cities() {

  const navigate = useNavigate();
  const [userRole, setUserRole] = useState(null);
  // الكوكيز والتوكن
  useEffect(() => {
    const checkAuth = async () => {
      try {
        const authDetails = await getAuthDetails();
        if (authDetails.role !== 'admin') {
            alert("الصفحة المطلوبة غير متوفرة")
          navigate('/login'); // إعادة التوجيه إذا لم يكن المستخدم Admin
        } else {
          setUserRole(authDetails.role); // تعيين الدور
        }
      } catch (error) {

        navigate('/login'); // إعادة التوجيه عند حدوث خطأ
      }
    };
    checkAuth();
  }, [navigate]);

/*
  // تسجيل الخروج
  const handleLogout = async () => {
    try {
      await logout();
      navigate('/login');
    } catch (error) {

    }
  };
*/

  // المدن
  const [cities, setCities] = useState([]);
  const [areas, setAreas] = useState([]);
  const [newCity, setNewCity] = useState('');
  const [selectedArea, setSelectedArea] = useState('');
  const [editId, setEditId] = useState(null);
  const [editCity, setEditCity] = useState('');
  const [editArea, setEditArea] = useState('');

  // جلب المناطق والمدن عند تحميل الصفحة
  useEffect(() => {
    fetchAreas();
    fetchCities();
  }, []);

  const fetchAreas = async () => {
    try {
      const response = await axios.get('https://ads2030.com/api/areas');
      setAreas(response.data);
    } catch (error) {

    }
  };

  const fetchCities = async () => {
    try {
      const response = await axios.get('https://ads2030.com/api/cities');
      setCities(response.data);
    } catch (error) {

    }
  };

  const addCity = async (e) => {
    e.preventDefault();

    try {
      const response = await axios.post('https://ads2030.com/api/cities/add', {
        city: newCity,
        areas_id: selectedArea,
      });
      setCities([
        ...cities,
        { id: response.data.id, city: newCity, areas_id: selectedArea, area: areas.find((a) => a.id === +selectedArea)?.area },
      ]);
      setNewCity('');
      setSelectedArea('');
    } catch (error) {

    }
  };

  const deleteCity = async (id) => {
    try {
      await axios.delete(`https://ads2030.com/api/cities/delete/${id}`);
      setCities(cities.filter((c) => c.id !== id));
    } catch (error) {

    }
  };

  const startEdit = (id, city, areas_id) => {
    setEditId(id);
    setEditCity(city);
    setEditArea(areas_id);
  };

  const saveEdit = async () => {
    try {
      await axios.put(`https://ads2030.com/api/cities/edit/${editId}`, {
        city: editCity,
        areas_id: editArea,
      });
      setCities(
        cities.map((c) =>
          c.id === editId ? { ...c, city: editCity, areas_id: editArea, area: areas.find((a) => a.id === +editArea)?.area } : c
        )
      );
      setEditId(null);
      setEditCity('');
      setEditArea('');
    } catch (error) {

    }
  };

  const cancelEdit = () => {
    setEditId(null);
    setEditCity('');
    setEditArea('');
  };

  return (
    <div className="cities-page">

  {userRole && <>
       <h1 className="cities-title">أضف مدينة جديدة</h1>

              {/* فورم إضافة مدينة جديدة */}
      <form onSubmit={addCity} className="cities-form">
        <input
          type="text"
          value={newCity}
          onChange={(e) => setNewCity(e.target.value)}
          placeholder="اسم المدينة"
          required
        />
        <select value={selectedArea} onChange={(e) => setSelectedArea(e.target.value)} required>
          <option value="">اختر المنطقة</option>
          {areas.map((area) => (
            <option key={area.id} value={area.id}>
              {area.area}
            </option>
          ))}
        </select>
        <button className="btn-add-city" type="submit">إضافة مدينة</button>
      </form>

      {/* قائمة المدن */}
      <ul className="city-list">
  {cities.map((city) => (
    <li key={city.id} className="city-item">
      {editId === city.id ? (
        <>
          <input
            type="text"
            className="city-input"
            value={editCity}
            onChange={(e) => setEditCity(e.target.value)}
          />
          <select
            className="area-select"
            value={editArea}
            onChange={(e) => setEditArea(e.target.value)}
          >
            {areas.map((area) => (
              <option key={area.id} value={area.id}>
                {area.area}
              </option>
            ))}
          </select>
          <button onClick={saveEdit} className="btn-save">
            حفظ
          </button>
          <button onClick={cancelEdit} className="btn-cancel">
            تراجع
          </button>
        </>
      ) : (
        <>
          <input
            type="text"
            className="city-display"
            value={`${city.city} - (${city.area})`}
            disabled
          />
          <button onClick={() => startEdit(city.id, city.city, city.areas_id)} className="btn-edit">
            تعديل
          </button>
          <button onClick={() => deleteCity(city.id)} className="btn-delete">
            حذف
          </button>
        </>
      )}
    </li>
  ))}
</ul>


      </>}
        
    </div>
  )
}

export default Cities