import React, { useEffect, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { getAuthDetails,/* logout */} from '../authService';
import axios from 'axios';
import './UserAdsall.css'

const UserAdsall = ({ onViewDetails }) => {
  const navigate = useNavigate();
  const [userRole, setUserRole] = useState(null);

  // التحقق من التوكن
  useEffect(() => {
    const checkAuth = async () => {
      try {
        const authDetails = await getAuthDetails();
        if (authDetails.role !== 'user') {
          alert("الصفحة المطلوبة غير متوفرة")
          navigate('/login'); // إعادة التوجيه إذا لم يكن المستخدم User
        } else {
          setUserRole(authDetails.role); // تعيين الدور
        }
      } catch (error) {
        navigate('/login'); // إعادة التوجيه عند حدوث خطأ
      }
    };
    checkAuth();
  }, [navigate]);

/*
  // تسجيل الخروج
  const handleLogout = async () => {
    try {
      await logout();
      navigate('/login');
    } catch (error) {
      console.error(error.message);
    }
  };
*/
  // اعلانات العضو
  const [ads, setAds] = useState([]);
  const [userDetails, setUserDetails] = useState(null);

  const [visibleAdsCount, setVisibleAdsCount] = useState(5); // عدد الإعلانات المرئية
  const adsPerPage = 5; // عدد الإعلانات لكل صفحة

  // جلب بيانات المستخدم
  useEffect(() => {
    const fetchUserData = async () => {
      try {
        const response = await axios.get('https://ads2030.com/api/userme/me', {
          withCredentials: true,
        });
        setUserDetails(response.data);
      } catch (error) {
        alert('Unauthorized: Please login again.');
        navigate('/login');
      }
    };

    fetchUserData();
  }, [navigate]);

  // جلب الإعلانات المرتبطة بالمستخدم
  useEffect(() => {
    const fetchAds = async () => {
      if (!userDetails) return;

      try {
        const adsResponse = await axios.get('https://ads2030.com/api/useradsall/all', {
          params: { useradsid: userDetails.username },
          withCredentials: true,
        });
        setAds(adsResponse.data);
      } catch (error) {

      }
    };

    fetchAds();
  }, [userDetails]);

    // زر اظهار المزيد من الإعلانات المرئية فقط
    useEffect(() => {
      const fetchAds = async () => {
        try {
          const response = await axios.get("https://ads2030.com/api/public-ads");
          setAds(response.data);
        } catch (error) {

        }
      };
  
      fetchAds();
    }, []);
    const visibleAds = ads.slice(0, visibleAdsCount);
    const handleLoadMore = () => {
      setVisibleAdsCount((prevCount) => prevCount + adsPerPage);
    };

  if (!userDetails) {
    return <p>جاري تحميل البيانات...</p>;
  }

  return (
    <div className='useradsall'>

      {userRole && <>
          <h1 className="user-ads-title">إعلاناتي</h1>

          { // ads عرض جميع الاعلانات
          visibleAds.length > 0 ? ( <>
            <table className="user-ads-table">
            {/* <thead>
                <tr>
                  <th>صورة الإعلان</th>
                  <th>عنوان الإعلان</th>
                  <th>المنطقة</th>
                  <th>المدينة</th>
                  <th>صاحب الاعلان</th>
                  <th>تاريخ الإعلان</th>
                </tr>
              </thead> */} 
              <tbody>
              { // ads عرض جميع الاعلانات
                visibleAds.map((ad) => (
                  <tr key={ad.id}>
                {/* صورة الإعلان */}
                <td className=".user-ads-image">
                  {ad.img1 && (
                    <button onClick={() => onViewDetails(ad.id)}>
                      <img
                        src={`https://ads2030.com/uploadsads/${ad.img1}`}
                        alt="صورة الإعلان"
                        className=".user-ads-thumbnail"
                      />
                    </button>
                  )}
                </td>                   
                {/* عنوان الإعلان */}
                <td className=".user-ad-title">
                  <p onClick={() => onViewDetails(ad.id)} className="admin-ads-link">
                    {ad.adresads}
                  </p>
                </td>

                    <td>{ad.area || 'غير متوفرة'}</td>  
                    <td>{ad.city || 'غير متوفرة'}</td>  
                    <td>{ad.useradsid || 'غير متوفرة'}</td>
                    <td>{new Date(ad.datestart).toLocaleDateString('en-GB').replace(/\//g, '-')}</td>
                  </tr>
                ))}
              </tbody>
            </table>

            {/* زر إظهار المزيد */}
            {visibleAdsCount < ads.length && (
              <button className="load-more-button" onClick={handleLoadMore}>
                إظهار المزيد
              </button>
            )}   

            </>
          ) : (
            <p className="no-ads-message">لا توجد إعلانات لعرضها.</p>
          )}
        </>
      }

    </div>
  );
};


export default UserAdsall