import React, { useEffect, useState } from 'react';
import { Link, useNavigate, useParams  } from 'react-router-dom';
import { getAuthDetails, logout } from '../authService';
import axios from 'axios';

const UserAdsedit = () => {

  const navigate = useNavigate();
  const [userRole, setUserRole] = useState(null);
  
  useEffect(() => {
    const checkAuth = async () => {
      try {
        const authDetails = await getAuthDetails();
        if (authDetails.role !== 'user') {
          alert("الصفحة المطلوبة غير متوفرة")
          navigate('/login'); // إعادة التوجيه إذا لم يكن المستخدم User
        } else {
          setUserRole(authDetails.role); // تعيين الدور
        }
      } catch (error) {
        navigate('/login'); // إعادة التوجيه عند حدوث خطأ
      }
    };
    checkAuth();
  }, [navigate]);

  const handleLogout = async () => {
    try {
      await logout();
      navigate('/login');
    } catch (error) {
      console.error(error.message);
    }
  };

  // تعديل الاعلان
  const { id } = useParams();
  const [editData, setEditData] = useState({});
  const [newImages, setNewImages] = useState({ img1: null, img2: null, img3: null });

  // جلب تفاصيل الإعلان
  useEffect(() => {
    const fetchAdDetails = async () => {
      try {
        const response = await axios.get(`https://ads2030.com/api/useradsedit/show/${id}`, {
          withCredentials: true,
        });
        setEditData(response.data);
      } catch (error) {

      }
    };

    fetchAdDetails();
  }, [id]);

  const handleInputChange = (e) => {
    const { name, value } = e.target;
    setEditData((prev) => ({ ...prev, [name]: value }));
  };

  const handleImageChange = (e) => {
    const { name, files } = e.target;
    setNewImages((prev) => ({ ...prev, [name]: files[0] }));
  };

  const saveEdit = async () => {
    const formData = new FormData();
    for (const key in editData) {
      formData.append(key, editData[key]);
    }
    for (const key in newImages) {
      if (newImages[key]) {
        formData.append(key, newImages[key]);
      }
    }

    try {
      const response = await axios.put(`https://ads2030.com/api/useradsedit/update/${id}`, formData, {
        headers: { 'Content-Type': 'multipart/form-data' },
        withCredentials: true,
      });
      alert(response.data.message);
      navigate(`/useradsshow/${id}`); // العودة إلى تفاصيل الإعلان
    } catch (error) {

      alert('حدث خطأ أثناء تعديل الإعلان.');
    }
  };


  return (
    <div className='useradsedit'>

      {userRole && <>

        <button style={{background:"red", color:"white"}} onClick={handleLogout}>تسجيل الخروج</button>
        <button><Link to='/userindex'>الرئيسية</Link></button>
        <button><Link to='/userme'>بياناتي</Link></button>
        <button><Link to='/userads'>إعلان جديد</Link></button>
        <button><Link to='/useradsall'>إعلاناتي</Link></button>
         <br />
       <h1>صفحة تعديل الاعلان</h1> 

       <form>
        <div>
          <label>العنوان:</label>
          <input
            type="text"
            name="adresads"
            value={editData.adresads || ''}
            onChange={handleInputChange}
          />
        </div>
        <div>
          <label>الوصف:</label>
          <textarea
            name="textads"
            value={editData.textads || ''}
            onChange={handleInputChange}
          />
        </div>
        <div>
          <label>السعر:</label>
          <input
            type="number"
            name="cash"
            value={editData.cash || ''}
            onChange={handleInputChange}
          />
        </div>
        <div>
          <label>السعر:</label>
          <input
            type="number"
            name="model"
            value={editData.modelid || ''}
            onChange={handleInputChange}
          />
        </div>
        <div>
          <label>تحديث الصور:</label>
          <input type="file" name="img1" onChange={handleImageChange} />
          <input type="file" name="img2" onChange={handleImageChange} />
          <input type="file" name="img3" onChange={handleImageChange} />
        </div>
        <button type="button" onClick={saveEdit}>حفظ التعديلات</button>
        <button type="button" onClick={() => navigate(`/useradsshow/${id}`)}>تراجع</button>
      </form>

      </>}

    </div>
  );
};

export default UserAdsedit;