import React, { useEffect, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { getAuthDetails, logout } from '../authService';
import UserAds from './UserAds';
import UserAdsall from './UserAdsall';
import UserAdsshow from './UserAdsshow';
import UserMe from './UserMe';
import './UserIndex.css';
import axios from 'axios';

const UserIndex = () => {
  const navigate = useNavigate();
  const [userRole, setUserRole] = useState(null);

  const [activePage, setActivePage] = useState('dashboard'); // الصفحة الافتراضية
  const [userDetails, setUserDetails] = useState(null);
    const [activeAdId, setActiveAdId] = useState(null); // لتخزين معرف الإعلان النشط


  
  useEffect(() => {
    const checkAuth = async () => {
      try {
        const authDetails = await getAuthDetails();
        if (authDetails.role !== 'user') {
          alert("الصفحة المطلوبة غير متوفرة")
          navigate('/login'); // إعادة التوجيه إذا لم يكن المستخدم User
        } else {
          setUserRole(authDetails.role); // تعيين الدور
        }
      } catch (error) {
        navigate('/login'); // إعادة التوجيه عند حدوث خطأ
      }
    };
    checkAuth();
  }, [navigate]);

  const handleLogout = async () => {
    try {
      await logout();
      navigate('/login');
    } catch (error) {

    }
  };

        // جلب بيانات المستخدم بعد تسجيل الدخول
        useEffect(() => {
          const fetchUserData = async () => {
            try {
              const response = await axios.get('https://ads2030.com/api/userme/me', { withCredentials: true });
              setUserDetails(response.data);
            } catch (error) {
              alert('عفواً: يجب تسجيل الدخول');
              navigate('/login');
            }
          };
          fetchUserData();
        }, [navigate]);

    // عرض الصفحة بناءً على الحالة
    const renderPage = () => {

      if (activePage === 'useradsshow') {
        return (
          <UserAdsshow
            adId={activeAdId} // تمرير معرف الإعلان
            onBack={() => setActivePage('useradsall')} // العودة إلى صفحة الإعلانات
          />
        );
      }
    
      if (activePage === 'useradsall') {
        return (
          <UserAdsall
            onViewDetails={(id) => {
              setActiveAdId(id); // تعيين معرف الإعلان
              setActivePage('useradsshow'); // التبديل إلى صفحة تفاصيل الإعلان
            }}
          />
        );
      }

      switch (activePage) {
        case 'dashboard':
          return <h2>مرحبًا بك في لوحة تحكم المستخدم
            <><br />
            <img
                src={`https://ads2030.com/uploadsadmin/${userDetails?.image || 'default.png'}`}
                alt="User"
               // className="user-avatar"
                style={{marginTop:"20px",width:"40%", borderRadius:"50%"}}
              />
            </>
          </h2>;

case "userads":
  return <UserAds onAdAdded={() => setActivePage("useradsall")} />;
case "useradsall":
  return <UserAdsall />;  
  case "useradsshow":
    return <UserAdsshow onBack={() => setActivePage("useradsall")} />;
    case 'useradsall':
      return <UserAdsall />;
        case 'userme':
          return <UserMe />;
        case 'userads':
          return <UserAds />;
        default:
          return <h2>الصفحة غير موجودة</h2>;
      }
    };



    return (
      <div className="user-index">
        {userRole && (
          <>
            {/* الهيدر */}
            <header className="user-header">
              <h1 className="user-title">لوحة تحكم المستخدم</h1>
              <button className="logout-button" onClick={handleLogout}>
                تسجيل الخروج
              </button>
            </header>
  
            {/* الهيدر الثاني */}
            <div className="user-subheader">
              <span className="user-name">أهلاً وسهلاً {userDetails?.username}</span>
              <img
                src={`https://ads2030.com/uploadsadmin/${userDetails?.image || 'default.png'}`}
                alt="User"
                className="user-avatar"
              />
            </div>
  
            {/* الجسم الرئيسي */}
            <div className="user-main">
              {/* القائمة الجانبية */}
              <aside className="user-sidebar">
                <nav>
                  <ul>
                    <li>
                      <button onClick={() => setActivePage('dashboard')}>الرئيسية</button>
                    </li>
                    <li>
                      <button onClick={() => setActivePage('userads')}>إعلان جديد</button>
                    </li>
                    <li>
                      <button onClick={() => setActivePage('useradsall')}>إعلاناتي</button>
                    </li>                    
                    <li>
                      <button onClick={() => setActivePage('userme')}>بياناتي</button>
                    </li>

                  </ul>
                </nav>
              </aside>
  
              {/* محتوى القسم الأيمن */}
              <section className="user-content">{renderPage()}</section>
            </div>
  
            {/* الفوتر */}
            <footer className="user-footer">2025 © ads2030.com الحقوق محفوظة لـ</footer>
          </>
        )}
      </div>
    );
  };
  
  export default UserIndex;
