import React, { useEffect, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { getAuthDetails,/* logout */} from '../authService';
import axios from 'axios';
import './UserMe.css';

const UserMe = () => {
  const navigate = useNavigate();
  const [userRole, setUserRole] = useState(null);
  useEffect(() => {
    const checkAuth = async () => {
      try {
        const authDetails = await getAuthDetails();
        if (authDetails.role !== 'user') {
          alert("الصفحة المطلوبة غير متوفرة")
          navigate('/login'); // إعادة التوجيه إذا لم يكن المستخدم User
        } else {
          setUserRole(authDetails.role); // تعيين الدور
        }
      } catch (error) {
        console.error('Unauthorized:', error.message);
        navigate('/login'); // إعادة التوجيه عند حدوث خطأ
      }
    };
    checkAuth();
  }, [navigate]);
/*
  const handleLogout = async () => {
    try {
      await logout();
      navigate('/login');
    } catch (error) {
      console.error(error.message);
    }
  };
*/
  const [userDetails, setUserDetails] = useState(null);

  // جلب بيانات المستخدم بعد تسجيل الدخول
  useEffect(() => {
    const fetchUserData = async () => {
      try {
        const response = await axios.get('https://ads2030.com/api/userme/me', { withCredentials: true });
        setUserDetails(response.data);
      } catch (error) {
        console.error('Error fetching user data:', error.message);
        alert('Unauthorized: Please login again.');
        navigate('/login');
      }
    };
    fetchUserData();
  }, [navigate]);

  const [isEditing, setIsEditing] = useState(false);
  const [editData, setEditData] = useState({});
  const [newImage, setNewImage] = useState(null);

  const handleEdit = () => {
    setIsEditing(true);
    setEditData({
      username: userDetails.username,
      phone: userDetails.phone,
      password: '',
    });
  };

  const handleInputChange = (e) => {
    const { name, value } = e.target;
    setEditData((prev) => ({ ...prev, [name]: value }));
  };

  const handleImageChange = (e) => {
    setNewImage(e.target.files[0]);
  };

  const saveEdit = async () => {
    const formData = new FormData();
    for (const key in editData) {
      formData.append(key, editData[key]);
    }
    if (newImage) {
      formData.append('image', newImage);
    }
  
    try {
      const response = await axios.put('https://ads2030.com/api/userupdate/update', formData, {
        headers: { 'Content-Type': 'multipart/form-data' },
        withCredentials: true,
      });
      alert(response.data.message);
      setIsEditing(false);
      setUserDetails((prev) => ({
        ...prev,
        username: editData.username,
        phone: editData.phone,
        image: newImage ? newImage.name : prev.image,
      }));
    } catch (error) {
      alert('حدث خطأ أثناء تحديث البيانات.');
    }
  };
  

  const deleteAccount = async () => {
    if (window.confirm('هل أنت متأكد أنك تريد حذف الحساب؟')) {
      try {
        const response = await axios.delete('https://ads2030.com/api/userdelete/delete', {
          withCredentials: true,
        });
        alert(response.data.message);
        navigate('/login');
      } catch (error) {
        alert('حدث خطأ أثناء حذف الحساب.');
      }
    }
  };
  

  if (!userDetails) {
    return <p>جاري تحميل البيانات...</p>;
  }

  return (
    <div className='userme-page'>

      {userRole && <>

      {/* <div><h2 style={{direction:"rtl", float:"right"}}>مرحباً بك {userDetails.username}</h2></div> */}
      <div className="user-details-container">
      <h1>بياناتي</h1>

      <div className="user-image">
        <img
          src={`https://ads2030.com/uploadsadmin/${userDetails.image}`}
          alt="صورة المستخدم"
        />
      </div>

      <div className="user-info">
        <p>
          <strong>اسم المستخدم:</strong> {userDetails.username}
        </p>
        <p>
          <strong>البريد الإلكتروني:</strong> {userDetails.email}
        </p>
        <p>
          <strong>رقم الهاتف:</strong> {userDetails.phone}
        </p>
        <p>
          <strong>المرتبة:</strong>{' '}
          {userDetails.role === 'admin' ? 'مدير' : 'عضو'}
        </p>
        <p>
          <strong>تاريخ التسجيل:</strong>{' '}
          {new Date(userDetails.registration_date)
            .toLocaleDateString('en-GB')
            .replace(/\//g, '-')}
        </p>
      </div>

      <div className="user-actions">
        <button className="edit-button" onClick={handleEdit}>
          تعديل
        </button>
        <button className="delete-button" onClick={deleteAccount}>
          حذف الحساب
        </button>
      </div>
    </div>

       {/* الواجهة الخلفية UserUpdate.js */}
          {isEditing && (
            <div style={{width:"400px", margin:"10px auto", background: '#f9f9f9', padding: '20px', borderRadius: '10px', marginTop: '20px' }}>
              <h2>تعديل بيانات المستخدم</h2>
              <form className='formedit'>
                <div>
                  <label>اسم المستخدم:</label><br />
                  <input
                    type="text"
                    name="username"
                    value={editData.username}
                    onChange={handleInputChange}
                    placeholder="اسم المستخدم"
                  />
                </div>
                <div>
                  <label>رقم الهاتف:</label><br />
                  <input
                    type="text"
                    name="phone"
                    value={editData.phone}
                    onChange={handleInputChange}
                    placeholder="رقم الهاتف"
                  />
                </div>
                <div>
                  <label>كلمة المرور (اختياري):</label><br />
                  <input
                    type="password"
                    name="password"
                    value={editData.password}
                    onChange={handleInputChange}
                    placeholder="كلمة المرور الجديدة"
                  />
                </div>
                <div>
                  <label>تحديث الصورة:</label>
                  <input type="file" onChange={handleImageChange} />
                </div>
                <div>
                  <button style={{background:"green", marginLeft:"5px",marginRight:"5px"}} type="button" onClick={saveEdit}>
                    حفظ التعديلات
                  </button>
                  <button style={{background:"gray"}} type="button" onClick={() => setIsEditing(false)}>
                    إلغاء
                  </button>
                  <p>لتعديل الإيميل والمرتبة التواصل مع الإدارة</p>
                </div>
              </form>
            </div>
          )}

      </>}

    </div>
  );
};

export default UserMe